@@ -1,6 +1,6 @@
 #!/bin/sh
 
-PEMFILE="/etc/mw/xvnc.pem"
+PEMFILE="/etc/hubzero/xvnc.pem"
 
 # Generate new certs if needed
 if [ -e $PEMFILE ]; then
